==> angular2_mdl-0.1.2.tar.gz: lib/src/components/MaterialLayout.dart <==
part of mdlcomponents;

import 'package:angular2/angular2.dart';


class Link {
	final String label;
	Link(String this.label);
}

class cssClass {
	final string name;
	bool state;
	cssClass(string this.name,bool this.state);
}
@Component(
	selector: 'material-layout',
	directives: const [NgIf,NgFor,NgClass],
	templateUrl: 'MaterialLayout.html'
)
class MaterialLayout {

    static const _MaterialLayoutConstant _constant = const _MaterialLayoutConstant();
    static const _MaterialLayoutCssClasses _cssClasses = const _MaterialLayoutCssClasses();
    static const _MaterialLayoutMode _mode = const _MaterialLayoutMode();

    //dom.HtmlElement _header = null;
    bool _header = false;
    //dom.HtmlElement _drawer = null;
    bool _drawer = true;
    //dom.HtmlElement _tabBar = null;
    bool _tabBar;
    //dom.HtmlElement _content = null;
    bool _content = true;
    //dom.HtmlElement _obfuscator = null;
    bool _obfuscator;
    
    List links = [new Link('Link-A'),new Link('Link-B'),new Link('Link-C')];
    
    bool isActive = false;
    
    bool ariaHidden = true;
    bool ariaExpanded = false;
    
    string role = 'button';
    string tabindex = '0';
	string icon = _constant.MENU_ICON;
	Map<String,bool> drawerClass;
	Map<String,bool> obfuscatorClass;

    //dom.MediaQueryList _screenSizeMediaQuery = null;

    /// All the Tabs - necessary for downgrading
    //final List<MaterialLayoutTab> _tabs = new List<MaterialLayoutTab>();

    MaterialLayout(){
    drawerClass = {cssClasses.DRAWER:true,cssClasses.IS_DRAWER_OPEN:false};
    obfuscatorClass = {cssClasses.OBFUSCATOR:false};
    }
    
    bool get header => _header;
    
    bool get drawer => _drawer;

	bool get tolBar => _tolBar;
	
	bool get content => _content;
	
	bool get obfuscator => _obfuscator;
	
	bool get cssClasses => _cssClasses;

	void set header(value) {_header = value;}

	void toggle(){
		drawerClass[cssClasses.IS_DRAWER_OPEN] = !drawerClass[cssClasses.IS_DRAWER_OPEN];
		ariaHidden = !ariaHidden;
		ariaExpanded = !ariaExpanded;
		obfuscatorClass[cssClasses.OBFUSCATOR] = !obfuscatorClass[cssClasses.OBFUSCATOR];
		_obfuscator = !_obfuscator; 
	}
}


/// Keycodes, for code readability.
///
/// enum {number}
class _MaterialLayoutKeycodes {
    static const int ENTER = 13;
    static const int ESCAPE = 27;
    static const int SPACE = 32;
}

/// Modes.
class _MaterialLayoutMode {

    final int STANDARD = 0;
    final int SEAMED = 1;
    final int WATERFALL = 2;
    final int SCROLL = 3;

    const _MaterialLayoutMode();
}


/// Store strings for class names defined by this component that are used in
/// Dart. This allows us to simply change it in one place should we
/// decide to modify at a later date.
class _MaterialLayoutCssClasses {

    static const String MAIN_CLASS  = "mdl-layout";

    final String CONTAINER = 'mdl-layout__container';
    final String HEADER = 'mdl-layout__header';
    final String DRAWER = 'mdl-layout__drawer';
    final String CONTENT = 'mdl-layout__content';
    final String DRAWER_BTN = 'mdl-layout__drawer-button';

    final String ICON = 'material-icons';

    final String JS_RIPPLE_EFFECT = 'mdl-ripple-effect';
    final String RIPPLE_CONTAINER = 'mdl-layout__tab-ripple-container';
    final String RIPPLE = 'mdl-ripple';
    final String RIPPLE_IGNORE_EVENTS = 'mdl-ripple-effect--ignore-events';

    final String HEADER_SEAMED = 'mdl-layout__header--seamed';
    final String HEADER_WATERFALL = 'mdl-layout__header--waterfall';
    final String HEADER_SCROLL = 'mdl-layout__header--scroll';

    final String FIXED_HEADER = 'mdl-layout--fixed-header';
    final String OBFUSCATOR = 'mdl-layout__obfuscator';

    final String TAB_BAR = 'mdl-layout__tab-bar';
    final String TAB_CONTAINER = 'mdl-layout__tab-bar-container';
    final String TAB = 'mdl-layout__tab';
    final String TAB_BAR_BUTTON = 'mdl-layout__tab-bar-button';
    final String TAB_BAR_LEFT_BUTTON = 'mdl-layout__tab-bar-left-button';
    final String TAB_BAR_RIGHT_BUTTON = 'mdl-layout__tab-bar-right-button';
    final String TAB_MANUAL_SWITCH = 'mdl-layout__tab-manual-switch';
    final String PANEL = 'mdl-layout__tab-panel';

    final String NAVI_LINK = "mdl-navigation__link";

    final String HAS_DRAWER = 'has-drawer';
    final String HAS_TABS = 'has-tabs';
    final String HAS_SCROLLING_HEADER = 'has-scrolling-header';
    final String CASTING_SHADOW = 'is-casting-shadow';
    final String IS_COMPACT = 'is-compact';
    final String IS_SMALL_SCREEN = 'is-small-screen';
    final String IS_DRAWER_OPEN = 'is-visible';
    final String IS_ACTIVE = 'is-active';
    final String IS_UPGRADED = 'is-upgraded';
    final String IS_ANIMATING = 'is-animating';

    final String ON_LARGE_SCREEN = 'mdl-layout--large-screen-only';
    final String ON_SMALL_SCREEN  = 'mdl-layout--small-screen-only';

    const _MaterialLayoutCssClasses();
}

/// Store constants in one place so they can be updated easily.
class _MaterialLayoutConstant {

    final String MAX_WIDTH = '(max-width: 1024px)';
    final int TAB_SCROLL_PIXELS = 100;
    final int RESIZE_TIMEOUT = 100;

    final String MENU_ICON = '&#xE5D2;';
    final String CHEVRON_LEFT = 'chevron_left';
    final String CHEVRON_RIGHT = 'chevron_right';

    const _MaterialLayoutConstant();
}

==> angular2_mdl-0.1.3.tar.gz: lib/src/components/MaterialLayout.dart <==
part of mdlcomponents;

class Link {
	final String label;
	Link(String this.label);
}

class cssClass {
	final string name;
	bool state;
	cssClass(string this.name,bool this.state);
}
@Component(
	selector: 'material-layout',
	directives: const [NgIf,NgFor,NgClass],
	templateUrl: 'src/components/MaterialLayout.html'
)
class MaterialLayout {

    static const _MaterialLayoutConstant _constant = const _MaterialLayoutConstant();
    static const _MaterialLayoutCssClasses _cssClasses = const _MaterialLayoutCssClasses();
    static const _MaterialLayoutMode _mode = const _MaterialLayoutMode();

    //dom.HtmlElement _header = null;
    bool _header = false;
    //dom.HtmlElement _drawer = null;
    bool _drawer = true;
    //dom.HtmlElement _tabBar = null;
    bool _tabBar;
    //dom.HtmlElement _content = null;
    bool _content = true;
    //dom.HtmlElement _obfuscator = null;
    bool _obfuscator;
    
    List links = [new Link('Link-A'),new Link('Link-B'),new Link('Link-C')];
    
    bool isActive = false;
    
    bool ariaHidden = true;
    bool ariaExpanded = false;
    
    string role = 'button';
    string tabindex = '0';
	string icon = _constant.MENU_ICON;
	Map<String,bool> drawerClass;
	Map<String,bool> obfuscatorClass;

    //dom.MediaQueryList _screenSizeMediaQuery = null;

    /// All the Tabs - necessary for downgrading
    //final List<MaterialLayoutTab> _tabs = new List<MaterialLayoutTab>();

    MaterialLayout(){
    drawerClass = {cssClasses.DRAWER:true,cssClasses.IS_DRAWER_OPEN:false};
    obfuscatorClass = {cssClasses.OBFUSCATOR:false};
    }
    
    bool get header => _header;
    
    bool get drawer => _drawer;

	bool get tolBar => _tolBar;
	
	bool get content => _content;
	
	bool get obfuscator => _obfuscator;
	
	bool get cssClasses => _cssClasses;

	void set header(value) {_header = value;}

	void toggle(){
		drawerClass[cssClasses.IS_DRAWER_OPEN] = !drawerClass[cssClasses.IS_DRAWER_OPEN];
		ariaHidden = !ariaHidden;
		ariaExpanded = !ariaExpanded;
		obfuscatorClass[cssClasses.OBFUSCATOR] = !obfuscatorClass[cssClasses.OBFUSCATOR];
		_obfuscator = !_obfuscator; 
	}
}


/// Keycodes, for code readability.
///
/// enum {number}
class _MaterialLayoutKeycodes {
    static const int ENTER = 13;
    static const int ESCAPE = 27;
    static const int SPACE = 32;
}

/// Modes.
class _MaterialLayoutMode {

    final int STANDARD = 0;
    final int SEAMED = 1;
    final int WATERFALL = 2;
    final int SCROLL = 3;

    const _MaterialLayoutMode();
}


/// Store strings for class names defined by this component that are used in
/// Dart. This allows us to simply change it in one place should we
/// decide to modify at a later date.
class _MaterialLayoutCssClasses {

    static const String MAIN_CLASS  = "mdl-layout";

    final String CONTAINER = 'mdl-layout__container';
    final String HEADER = 'mdl-layout__header';
    final String DRAWER = 'mdl-layout__drawer';
    final String CONTENT = 'mdl-layout__content';
    final String DRAWER_BTN = 'mdl-layout__drawer-button';

    final String ICON = 'material-icons';

    final String JS_RIPPLE_EFFECT = 'mdl-ripple-effect';
    final String RIPPLE_CONTAINER = 'mdl-layout__tab-ripple-container';
    final String RIPPLE = 'mdl-ripple';
    final String RIPPLE_IGNORE_EVENTS = 'mdl-ripple-effect--ignore-events';

    final String HEADER_SEAMED = 'mdl-layout__header--seamed';
    final String HEADER_WATERFALL = 'mdl-layout__header--waterfall';
    final String HEADER_SCROLL = 'mdl-layout__header--scroll';

    final String FIXED_HEADER = 'mdl-layout--fixed-header';
    final String OBFUSCATOR = 'mdl-layout__obfuscator';

    final String TAB_BAR = 'mdl-layout__tab-bar';
    final String TAB_CONTAINER = 'mdl-layout__tab-bar-container';
    final String TAB = 'mdl-layout__tab';
    final String TAB_BAR_BUTTON = 'mdl-layout__tab-bar-button';
    final String TAB_BAR_LEFT_BUTTON = 'mdl-layout__tab-bar-left-button';
    final String TAB_BAR_RIGHT_BUTTON = 'mdl-layout__tab-bar-right-button';
    final String TAB_MANUAL_SWITCH = 'mdl-layout__tab-manual-switch';
    final String PANEL = 'mdl-layout__tab-panel';

    final String NAVI_LINK = "mdl-navigation__link";

    final String HAS_DRAWER = 'has-drawer';
    final String HAS_TABS = 'has-tabs';
    final String HAS_SCROLLING_HEADER = 'has-scrolling-header';
    final String CASTING_SHADOW = 'is-casting-shadow';
    final String IS_COMPACT = 'is-compact';
    final String IS_SMALL_SCREEN = 'is-small-screen';
    final String IS_DRAWER_OPEN = 'is-visible';
    final String IS_ACTIVE = 'is-active';
    final String IS_UPGRADED = 'is-upgraded';
    final String IS_ANIMATING = 'is-animating';

    final String ON_LARGE_SCREEN = 'mdl-layout--large-screen-only';
    final String ON_SMALL_SCREEN  = 'mdl-layout--small-screen-only';

    const _MaterialLayoutCssClasses();
}

/// Store constants in one place so they can be updated easily.
class _MaterialLayoutConstant {

    final String MAX_WIDTH = '(max-width: 1024px)';
    final int TAB_SCROLL_PIXELS = 100;
    final int RESIZE_TIMEOUT = 100;

    final String MENU_ICON = '&#xE5D2;';
    final String CHEVRON_LEFT = 'chevron_left';
    final String CHEVRON_RIGHT = 'chevron_right';

    const _MaterialLayoutConstant();
}
